Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-27 02:46:48 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-27 03:03:16 +0300
commit3051e2f4ae8fd3e72a43dd1e5d40893d0efec500 (patch)
tree6de62ee531c71705a8d86592770d26f8ecb75d1f /source/blender/editors/space_view3d
parentce104ca89643c4b0e6358fd22a2b056ecd603e62 (diff)
DNA: rename Lamp -> Light
- BKE_lamp -> BKE_light - Main.lamp -> light
Diffstat (limited to 'source/blender/editors/space_view3d')
-rw-r--r--source/blender/editors/space_view3d/view3d_gizmo_lamp.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/source/blender/editors/space_view3d/view3d_gizmo_lamp.c b/source/blender/editors/space_view3d/view3d_gizmo_lamp.c
index 0854a7e60c5..208470f76f4 100644
--- a/source/blender/editors/space_view3d/view3d_gizmo_lamp.c
+++ b/source/blender/editors/space_view3d/view3d_gizmo_lamp.c
@@ -45,7 +45,7 @@
#include "view3d_intern.h" /* own include */
/* -------------------------------------------------------------------- */
/** \name Spot Lamp Gizmos
* \{ */
static bool WIDGETGROUP_lamp_spot_poll(const bContext *C, wmGizmoGroupType *UNUSED(gzgt))
@@ -62,7 +62,7 @@ static bool WIDGETGROUP_lamp_spot_poll(const bContext *C, wmGizmoGroupType *UNUS
if (base && BASE_SELECTABLE(v3d, base)) {
Object *ob = base->object;
if (ob->type == OB_LAMP) {
- Lamp *la = ob->data;
+ Light *la = ob->data;
return (la->type == LA_SPOT);
}
}
@@ -90,7 +90,7 @@ static void WIDGETGROUP_lamp_spot_refresh(const bContext *C, wmGizmoGroup *gzgro
wmGizmo *gz = wwrapper->gizmo;
ViewLayer *view_layer = CTX_data_view_layer(C);
Object *ob = OBACT(view_layer);
- Lamp *la = ob->data;
+ Light *la = ob->data;
float dir[3];
negate_v3_v3(dir, ob->obmat[2]);
@@ -122,7 +122,7 @@ void VIEW3D_GGT_lamp_spot(wmGizmoGroupType *gzgt)
/** \} */
/* -------------------------------------------------------------------- */
/** \name Area Lamp Gizmos
* \{ */
/* scale callbacks */
@@ -132,7 +132,7 @@ static void gizmo_area_lamp_prop_matrix_get(
{
BLI_assert(gz_prop->type->array_length == 16);
float (*matrix)[4] = value_p;
- const Lamp *la = gz_prop->custom_func.user_data;
+ const Light *la = gz_prop->custom_func.user_data;
matrix[0][0] = la->area_size;
matrix[1][1] = ELEM(la->area_shape, LA_AREA_RECT, LA_AREA_ELLIPSE) ? la->area_sizey : la->area_size;
@@ -144,7 +144,7 @@ static void gizmo_area_lamp_prop_matrix_set(
{
const float (*matrix)[4] = value_p;
BLI_assert(gz_prop->type->array_length == 16);
- Lamp *la = gz_prop->custom_func.user_data;
+ Light *la = gz_prop->custom_func.user_data;
if (ELEM(la->area_shape, LA_AREA_RECT, LA_AREA_ELLIPSE)) {
la->area_size = len_v3(matrix[0]);
@@ -170,7 +170,7 @@ static bool WIDGETGROUP_lamp_area_poll(const bContext *C, wmGizmoGroupType *UNUS
if (base && BASE_SELECTABLE(v3d, base)) {
Object *ob = base->object;
if (ob->type == OB_LAMP) {
- Lamp *la = ob->data;
+ Light *la = ob->data;
return (la->type == LA_AREA);
}
}
@@ -198,7 +198,7 @@ static void WIDGETGROUP_lamp_area_refresh(const bContext *C, wmGizmoGroup *gzgro
wmGizmoWrapper *wwrapper = gzgroup->customdata;
ViewLayer *view_layer = CTX_data_view_layer(C);
Object *ob = OBACT(view_layer);
- Lamp *la = ob->data;
+ Light *la = ob->data;
wmGizmo *gz = wwrapper->gizmo;
copy_m4_m4(gz->matrix_basis, ob->obmat);
@@ -238,7 +238,7 @@ void VIEW3D_GGT_lamp_area(wmGizmoGroupType *gzgt)
/* -------------------------------------------------------------------- */
/** \name Lamp Target Gizmo
* \{ */
static bool WIDGETGROUP_lamp_target_poll(const bContext *C, wmGizmoGroupType *UNUSED(gzgt))
@@ -253,7 +253,7 @@ static bool WIDGETGROUP_lamp_target_poll(const bContext *C, wmGizmoGroupType *UN
if (base && BASE_SELECTABLE(v3d, base)) {
Object *ob = base->object;
if (ob->type == OB_LAMP) {
- Lamp *la = ob->data;
+ Light *la = ob->data;
return (ELEM(la->type, LA_SUN, LA_SPOT, LA_AREA));
}
#if 0
@@ -297,7 +297,7 @@ static void WIDGETGROUP_lamp_target_draw_prepare(const bContext *C, wmGizmoGroup
unit_m4(gz->matrix_offset);
if (ob->type == OB_LAMP) {
- Lamp *la = ob->data;
+ Light *la = ob->data;
if (la->type == LA_SPOT) {
/* Draw just past the lamp size angle gizmo. */
madd_v3_v3fl(gz->matrix_basis[3], gz->matrix_basis[2], -la->spotsize);
@@ -45,7 +45,7 @@
#include "view3d_intern.h" /* own include */
/* -------------------------------------------------------------------- */
-/** \name Spot Lamp Gizmos
+/** \name Spot Light Gizmos
* \{ */
static bool WIDGETGROUP_lamp_spot_poll(const bContext *C, wmGizmoGroupType *UNUSED(gzgt))
@@ -122,7 +122,7 @@ void VIEW3D_GGT_lamp_spot(wmGizmoGroupType *gzgt)
/** \} */
/* -------------------------------------------------------------------- */
-/** \name Area Lamp Gizmos
+/** \name Area Light Gizmos
* \{ */
/* scale callbacks */
@@ -238,7 +238,7 @@ void VIEW3D_GGT_lamp_area(wmGizmoGroupType *gzgt)
/* -------------------------------------------------------------------- */
-/** \name Lamp Target Gizmo
+/** \name Light Target Gizmo
* \{ */
static bool WIDGETGROUP_lamp_target_poll(const bContext *C, wmGizmoGroupType *UNUSED(gzgt))